%define _disable_ld_no_undefined 1

%define major 0
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Summary:	Implementation of the PKCS#11 (Cryptoki) specification v2.11
Name:		opencryptoki
Version:	3.5
Release:	%mkrel 1
License:	CPL
Group:		System/Libraries
URL:		http://sourceforge.net/projects/opencryptoki
Source0:	http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tgz
Source1:	%{name}-tmpfiles.conf
# https://bugzilla.redhat.com/show_bug.cgi?id=732756
Patch0:		%{name}-2.4-group.patch
# do not install pkcsep11_migrate.1 and pkcscca.1 when it's not enabled
Patch1:		%{name}-3.2-conditional-manpages.patch
BuildRequires:	autoconf automake libtool
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	openldap-devel
BuildRequires:	openssl-devel
BuildRequires:	systemd-units
BuildRequires:	trousers-devel
%ifarch s390 s390x
BuildRequires:	libica-devel >= 2.0
%endif
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper

%description
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.
This package contains the Slot Daemon (pkcsslotd) and general utilities.

%package -n	%{libname}
Summary:	The run-time libraries for opencryptoki package
Group:		System/Libraries

%description -n	%{libname}
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.

This package contains the PKCS#11 library implementation, and requires
at least one token implementation (packaged separately) to be fully
functional.

%package -n	%{develname}
Summary:	Development files for openCryptoki
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the development header files for building
opencryptoki and PKCS#11 based applications

%package	swtok
Summary:	The software token implementation for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	swtok
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.

This package brings the software token implementation to use opencryptoki
without any specific cryptographic hardware.

%package	tpmtok
Summary:	Trusted Platform Module (TPM) device support for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	tpmtok
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.

This package brings the necessary libraries and files to support
Trusted Platform Module (TPM) devices in the opencryptoki stack.

%package	icsftok
Summary:	ICSF token support for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	icsftok
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.
This package brings the necessary libraries and files to support
ICSF token in the opencryptoki stack.


%ifarch s390 s390x
%package	icatok
Summary:	ICA cryptographic devices (clear-key) support for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	icatok
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.
This package brings the necessary libraries and files to support ICA
devices in the opencryptoki stack. ICA is an interface to IBM
cryptographic hardware such as IBM 4764 or 4765 that uses the
"accelerator" or "clear-key" path.

%package	ccatok
Summary:	CCA cryptographic devices (secure-key) support for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	ccatok
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.
This package brings the necessary libraries and files to support CCA
devices in the opencryptoki stack. CCA is an interface to IBM
cryptographic hardware such as IBM 4764 or 4765 that uses the
"co-processor" or "secure-key" path.

%package	ep11tok
Summary:	CCA cryptographic devices (secure-key) support for opencryptoki
Group:		System/Libraries
Requires:	%{libname} = %{version}

%description	ep11tok
Opencryptoki implements the PKCS#11 specification v2.11 for a set of
cryptographic hardware, such as IBM 4764 and 4765 crypto cards, and the
Trusted Platform Module (TPM) chip. Opencryptoki also brings a software
token implementation that can be used without any cryptographic
hardware.
This package brings the necessary libraries and files to support EP11
tokens in the opencryptoki stack. The EP11 token is a token that uses
the IBM Crypto Express adapters (starting with Crypto Express 4S adapters)
configured with Enterprise PKCS#11 (EP11) firmware.
%endif

%prep

%setup -q -n %{name}
%patch0 -p1 -b .group
%patch1 -p1 -b .man

# Upstream tarball has unnecessary executable perms set on the sources
find . -name '*.[ch]' -print0 | xargs -0 chmod -x

# append token specific subdirs to tmpfiles.d config
token_subdirs="icsf swtok tpm"
%ifarch s390 s390x
token_subdirs="$token_subdirs lite ccatok ep11tok"
%endif

cp -p %{SOURCE1} %{name}-tmpfiles.conf
for d in $token_subdirs
do
    echo "D /var/lock/opencryptoki/$d 0770 root pkcs11 -" >> %{name}-tmpfiles.conf
done

%build
./bootstrap.sh

export CFLAGS="%{optflags} -fgnu89-inline"
%configure2_5x \
    --sharedstatedir=/var/lib \
    --with-systemd=%{_unitdir} \
%ifarch s390 s390x
    --enable-icatok --enable-ccatok
%else
    --disable-icatok --disable-ccatok
%endif

%make CHGRP=/bin/true

%install

%makeinstall_std CHGRP=/bin/true

# Remove unwanted cruft
rm -f %{buildroot}%{_libdir}/%{name}/*.la
rm -f %{buildroot}%{_libdir}/%{name}/stdll/*.la

# systemd must create /var/lock/opencryptoki
install -d %{buildroot}%{_prefix}/lib/tmpfiles.d
install -m 0644 %{name}-tmpfiles.conf %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf

%pre
%_pre_useradd pkcs11 /dev/null /sbin/nologin

%post
%_tmpfilescreate %{name}
%_post_service pkcsslotd

%preun
%_preun_service pkcsslotd

%postun
%_postun_userdel pkcs11

%files
%doc ChangeLog FAQ README
%doc doc/openCryptoki-HOWTO.pdf
%doc doc/README.token_data
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/pkcsslotd.service
%{_sbindir}/pkcsconf
%{_sbindir}/pkcsslotd
%{_mandir}/man1/pkcsconf.1*
%{_mandir}/man5/%{name}.conf.5*
%{_mandir}/man7/%{name}.7*
%{_mandir}/man8/pkcsslotd.8*
%{_libdir}/opencryptoki/methods
%{_libdir}/pkcs11/methods
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}
%dir %attr(770,root,pkcs11) %ghost %{_localstatedir}/lock/%{name}
%dir %attr(770,root,pkcs11) %ghost %{_localstatedir}/lock/%{name}/*

%files -n %{libname}
%doc LICENSE
%{_sysconfdir}/ld.so.conf.d/*
# Unversioned .so symlinks usually belong to -devel packages, but opencryptoki
# needs them in the main package, because:
#   pkcs11_startup looks for opencryptoki/stdll/*.so, and
#   documentation suggests that programs should dlopen "PKCS11_API.so".
%dir %{_libdir}/opencryptoki
%{_libdir}/opencryptoki/libopencryptoki.*
%{_libdir}/opencryptoki/PKCS11_API.so
%dir %{_libdir}/opencryptoki/stdll
%dir %{_libdir}/pkcs11
%{_libdir}/pkcs11/libopencryptoki.so
%{_libdir}/pkcs11/PKCS11_API.so
%{_libdir}/pkcs11/stdll

%files -n %{develname}
%{_includedir}/%{name}/

%files swtok
%{_libdir}/opencryptoki/stdll/libpkcs11_sw.*
%{_libdir}/opencryptoki/stdll/PKCS11_SW.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/swtok/
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/swtok/TOK_OBJ/

%files tpmtok
%doc doc/README.tpm_stdll
%{_libdir}/opencryptoki/stdll/libpkcs11_tpm.*
%{_libdir}/opencryptoki/stdll/PKCS11_TPM.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/tpm/

%files icsftok
%doc doc/README.icsf_stdll
%{_sbindir}/pkcsicsf
%{_mandir}/man1/pkcsicsf.1*
%{_libdir}/opencryptoki/stdll/libpkcs11_icsf.*
%{_libdir}/opencryptoki/stdll/PKCS11_ICSF.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/icsf/

%ifarch s390 s390x
%files icatok
%{_libdir}/opencryptoki/stdll/libpkcs11_ica.*
%{_libdir}/opencryptoki/stdll/PKCS11_ICA.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/lite/
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/lite/TOK_OBJ/

%files ccatok
%doc doc/README-IBM_CCA_users
%doc doc/README.cca_stdll
%{_sbindir}/pkcscca
%{_mandir}/man1/pkcscca.1*
%{_libdir}/opencryptoki/stdll/libpkcs11_cca.*
%{_libdir}/opencryptoki/stdll/PKCS11_CCA.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/ccatok/
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/ccatok/TOK_OBJ/

%files ep11tok
%doc doc/README.ep11_stdll
%config(noreplace) %{_sysconfdir}/%{name}/ep11tok.conf
%{_sbindir}/pkcsep11_migrate
%{_mandir}/man1/pkcsep11_migrate.1.*
%{_libdir}/opencryptoki/stdll/libpkcs11_ep11.*
%{_libdir}/opencryptoki/stdll/PKCS11_EP11.so
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/ep11tok/
%dir %attr(770,root,pkcs11) %{_localstatedir}/lib/%{name}/ep11tok/TOK_OBJ/
%endif



%changelog
* Fri Aug 26 2016 luigiwalser <luigiwalser> 3.5-1.mga6
+ Revision: 1049124
- 3.5

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Tue Nov 17 2015 oden <oden> 3.4-1.mga6
+ Revision: 903815
- attempt to fix the %%ghost stuff
- fix deps
- 3.4
- sync with fedora

* Mon Nov 09 2015 daviddavid <daviddavid> 2.4.2-5.mga6
+ Revision: 899897
- fix compilation with gcc5: add -fgnu89-inline to CFLAGS

* Wed Oct 15 2014 umeabot <umeabot> 2.4.2-4.mga5
+ Revision: 740493
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.4.2-3.mga5
+ Revision: 683201
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2.4.2-2.mga4
+ Revision: 521330
- Mageia 4 Mass Rebuild

* Mon Jan 21 2013 oden <oden> 2.4.2-1.mga3
+ Revision: 390421
- don't ship the /var/lock/opencryptoki dir
- imported package opencryptoki

